SWDEV-351980 - Update hip_prof_str.h
Change-Id: Ied27c137aff54e69dc14129e6daad9196479edf9
Cette révision appartient à :
@@ -18,347 +18,347 @@ enum hip_api_id_t {
|
||||
HIP_API_ID_hipArrayDestroy = 5,
|
||||
HIP_API_ID_hipChooseDevice = 6,
|
||||
HIP_API_ID_hipConfigureCall = 7,
|
||||
HIP_API_ID_hipCtxCreate = 8,
|
||||
HIP_API_ID_hipCtxDestroy = 9,
|
||||
HIP_API_ID_hipCtxDisablePeerAccess = 10,
|
||||
HIP_API_ID_hipCtxEnablePeerAccess = 11,
|
||||
HIP_API_ID_hipCtxGetApiVersion = 12,
|
||||
HIP_API_ID_hipCtxGetCacheConfig = 13,
|
||||
HIP_API_ID_hipCtxGetCurrent = 14,
|
||||
HIP_API_ID_hipCtxGetDevice = 15,
|
||||
HIP_API_ID_hipCtxGetFlags = 16,
|
||||
HIP_API_ID_hipCtxGetSharedMemConfig = 17,
|
||||
HIP_API_ID_hipCtxPopCurrent = 18,
|
||||
HIP_API_ID_hipCtxPushCurrent = 19,
|
||||
HIP_API_ID_hipCtxSetCacheConfig = 20,
|
||||
HIP_API_ID_hipCtxSetCurrent = 21,
|
||||
HIP_API_ID_hipCtxSetSharedMemConfig = 22,
|
||||
HIP_API_ID_hipCtxSynchronize = 23,
|
||||
HIP_API_ID_hipDestroyExternalMemory = 24,
|
||||
HIP_API_ID_hipDestroyExternalSemaphore = 25,
|
||||
HIP_API_ID_hipDeviceCanAccessPeer = 26,
|
||||
HIP_API_ID_hipDeviceComputeCapability = 27,
|
||||
HIP_API_ID_hipDeviceDisablePeerAccess = 28,
|
||||
HIP_API_ID_hipDeviceEnablePeerAccess = 29,
|
||||
HIP_API_ID_hipDeviceGet = 30,
|
||||
HIP_API_ID_hipDeviceGetAttribute = 31,
|
||||
HIP_API_ID_hipDeviceGetByPCIBusId = 32,
|
||||
HIP_API_ID_hipDeviceGetCacheConfig = 33,
|
||||
HIP_API_ID_hipDeviceGetLimit = 34,
|
||||
HIP_API_ID_hipDeviceGetName = 35,
|
||||
HIP_API_ID_hipDeviceGetP2PAttribute = 36,
|
||||
HIP_API_ID_hipDeviceGetPCIBusId = 37,
|
||||
HIP_API_ID_hipDeviceGetSharedMemConfig = 38,
|
||||
HIP_API_ID_hipDeviceGetStreamPriorityRange = 39,
|
||||
HIP_API_ID_hipDevicePrimaryCtxGetState = 40,
|
||||
HIP_API_ID_hipDevicePrimaryCtxRelease = 41,
|
||||
HIP_API_ID_hipDevicePrimaryCtxReset = 42,
|
||||
HIP_API_ID_hipDevicePrimaryCtxRetain = 43,
|
||||
HIP_API_ID_hipDevicePrimaryCtxSetFlags = 44,
|
||||
HIP_API_ID_hipDeviceReset = 45,
|
||||
HIP_API_ID_hipDeviceSetCacheConfig = 46,
|
||||
HIP_API_ID_hipDeviceSetSharedMemConfig = 47,
|
||||
HIP_API_ID_hipDeviceSynchronize = 48,
|
||||
HIP_API_ID_hipDeviceTotalMem = 49,
|
||||
HIP_API_ID_RESERVED_50 = 50,
|
||||
HIP_API_ID_hipDrvMemcpy2DUnaligned = 51,
|
||||
HIP_API_ID_hipDrvMemcpy3D = 52,
|
||||
HIP_API_ID_hipDrvMemcpy3DAsync = 53,
|
||||
HIP_API_ID_hipEventCreate = 54,
|
||||
HIP_API_ID_hipEventCreateWithFlags = 55,
|
||||
HIP_API_ID_hipEventDestroy = 56,
|
||||
HIP_API_ID_hipEventElapsedTime = 57,
|
||||
HIP_API_ID_hipEventQuery = 58,
|
||||
HIP_API_ID_hipEventRecord = 59,
|
||||
HIP_API_ID_hipEventSynchronize = 60,
|
||||
HIP_API_ID_hipExtGetLinkTypeAndHopCount = 61,
|
||||
HIP_API_ID_hipExtLaunchKernel = 62,
|
||||
HIP_API_ID_hipExtLaunchMultiKernelMultiDevice = 63,
|
||||
HIP_API_ID_hipExtMallocWithFlags = 64,
|
||||
HIP_API_ID_hipExtModuleLaunchKernel = 65,
|
||||
HIP_API_ID_hipExtStreamCreateWithCUMask = 66,
|
||||
HIP_API_ID_hipExtStreamGetCUMask = 67,
|
||||
HIP_API_ID_hipExternalMemoryGetMappedBuffer = 68,
|
||||
HIP_API_ID_hipFree = 69,
|
||||
HIP_API_ID_hipFreeArray = 70,
|
||||
HIP_API_ID_hipFreeHost = 71,
|
||||
HIP_API_ID_hipFreeMipmappedArray = 72,
|
||||
HIP_API_ID_hipFuncGetAttribute = 73,
|
||||
HIP_API_ID_hipFuncGetAttributes = 74,
|
||||
HIP_API_ID_hipFuncSetAttribute = 75,
|
||||
HIP_API_ID_hipFuncSetCacheConfig = 76,
|
||||
HIP_API_ID_hipFuncSetSharedMemConfig = 77,
|
||||
HIP_API_ID_hipGetDevice = 78,
|
||||
HIP_API_ID_hipGetDeviceCount = 79,
|
||||
HIP_API_ID_hipGetDeviceFlags = 80,
|
||||
HIP_API_ID_hipGetDeviceProperties = 81,
|
||||
HIP_API_ID_RESERVED_82 = 82,
|
||||
HIP_API_ID_hipGetErrorString = 83,
|
||||
HIP_API_ID_hipGetLastError = 84,
|
||||
HIP_API_ID_hipGetMipmappedArrayLevel = 85,
|
||||
HIP_API_ID_hipGetSymbolAddress = 86,
|
||||
HIP_API_ID_hipGetSymbolSize = 87,
|
||||
HIP_API_ID_hipHccModuleLaunchKernel = 88,
|
||||
HIP_API_ID_hipHostAlloc = 89,
|
||||
HIP_API_ID_hipHostFree = 90,
|
||||
HIP_API_ID_hipHostGetDevicePointer = 91,
|
||||
HIP_API_ID_hipHostGetFlags = 92,
|
||||
HIP_API_ID_hipHostMalloc = 93,
|
||||
HIP_API_ID_hipHostRegister = 94,
|
||||
HIP_API_ID_hipHostUnregister = 95,
|
||||
HIP_API_ID_hipImportExternalMemory = 96,
|
||||
HIP_API_ID_hipImportExternalSemaphore = 97,
|
||||
HIP_API_ID_hipInit = 98,
|
||||
HIP_API_ID_hipIpcCloseMemHandle = 99,
|
||||
HIP_API_ID_hipIpcGetEventHandle = 100,
|
||||
HIP_API_ID_hipIpcGetMemHandle = 101,
|
||||
HIP_API_ID_hipIpcOpenEventHandle = 102,
|
||||
HIP_API_ID_hipIpcOpenMemHandle = 103,
|
||||
HIP_API_ID_hipLaunchByPtr = 104,
|
||||
HIP_API_ID_hipLaunchCooperativeKernel = 105,
|
||||
HIP_API_ID_hipLaunchCooperativeKernelMultiDevice = 106,
|
||||
HIP_API_ID_hipLaunchKernel = 107,
|
||||
HIP_API_ID_hipMalloc = 108,
|
||||
HIP_API_ID_hipMalloc3D = 109,
|
||||
HIP_API_ID_hipMalloc3DArray = 110,
|
||||
HIP_API_ID_hipMallocArray = 111,
|
||||
HIP_API_ID_hipMallocHost = 112,
|
||||
HIP_API_ID_hipMallocManaged = 113,
|
||||
HIP_API_ID_hipMallocMipmappedArray = 114,
|
||||
HIP_API_ID_hipMallocPitch = 115,
|
||||
HIP_API_ID_hipMemAdvise = 116,
|
||||
HIP_API_ID_hipMemAllocHost = 117,
|
||||
HIP_API_ID_hipMemAllocPitch = 118,
|
||||
HIP_API_ID_hipMemGetAddressRange = 119,
|
||||
HIP_API_ID_hipMemGetInfo = 120,
|
||||
HIP_API_ID_hipMemPrefetchAsync = 121,
|
||||
HIP_API_ID_hipMemPtrGetInfo = 122,
|
||||
HIP_API_ID_hipMemRangeGetAttribute = 123,
|
||||
HIP_API_ID_hipMemRangeGetAttributes = 124,
|
||||
HIP_API_ID_hipMemcpy = 125,
|
||||
HIP_API_ID_hipMemcpy2D = 126,
|
||||
HIP_API_ID_hipMemcpy2DAsync = 127,
|
||||
HIP_API_ID_hipMemcpy2DFromArray = 128,
|
||||
HIP_API_ID_hipMemcpy2DFromArrayAsync = 129,
|
||||
HIP_API_ID_hipMemcpy2DToArray = 130,
|
||||
HIP_API_ID_hipMemcpy2DToArrayAsync = 131,
|
||||
HIP_API_ID_hipMemcpy3D = 132,
|
||||
HIP_API_ID_hipMemcpy3DAsync = 133,
|
||||
HIP_API_ID_hipMemcpyAsync = 134,
|
||||
HIP_API_ID_hipMemcpyAtoH = 135,
|
||||
HIP_API_ID_hipMemcpyDtoD = 136,
|
||||
HIP_API_ID_hipMemcpyDtoDAsync = 137,
|
||||
HIP_API_ID_hipMemcpyDtoH = 138,
|
||||
HIP_API_ID_hipMemcpyDtoHAsync = 139,
|
||||
HIP_API_ID_hipMemcpyFromArray = 140,
|
||||
HIP_API_ID_hipMemcpyFromSymbol = 141,
|
||||
HIP_API_ID_hipMemcpyFromSymbolAsync = 142,
|
||||
HIP_API_ID_hipMemcpyHtoA = 143,
|
||||
HIP_API_ID_hipMemcpyHtoD = 144,
|
||||
HIP_API_ID_hipMemcpyHtoDAsync = 145,
|
||||
HIP_API_ID_hipMemcpyParam2D = 146,
|
||||
HIP_API_ID_hipMemcpyParam2DAsync = 147,
|
||||
HIP_API_ID_hipMemcpyPeer = 148,
|
||||
HIP_API_ID_hipMemcpyPeerAsync = 149,
|
||||
HIP_API_ID_hipMemcpyToArray = 150,
|
||||
HIP_API_ID_hipMemcpyToSymbol = 151,
|
||||
HIP_API_ID_hipMemcpyToSymbolAsync = 152,
|
||||
HIP_API_ID_hipMemcpyWithStream = 153,
|
||||
HIP_API_ID_hipMemset = 154,
|
||||
HIP_API_ID_hipMemset2D = 155,
|
||||
HIP_API_ID_hipMemset2DAsync = 156,
|
||||
HIP_API_ID_hipMemset3D = 157,
|
||||
HIP_API_ID_hipMemset3DAsync = 158,
|
||||
HIP_API_ID_hipMemsetAsync = 159,
|
||||
HIP_API_ID_hipMemsetD16 = 160,
|
||||
HIP_API_ID_hipMemsetD16Async = 161,
|
||||
HIP_API_ID_hipMemsetD32 = 162,
|
||||
HIP_API_ID_hipMemsetD32Async = 163,
|
||||
HIP_API_ID_hipMemsetD8 = 164,
|
||||
HIP_API_ID_hipMemsetD8Async = 165,
|
||||
HIP_API_ID_hipModuleGetFunction = 166,
|
||||
HIP_API_ID_hipModuleGetGlobal = 167,
|
||||
HIP_API_ID_hipModuleGetTexRef = 168,
|
||||
HIP_API_ID_hipModuleLaunchKernel = 169,
|
||||
HIP_API_ID_hipModuleLoad = 170,
|
||||
HIP_API_ID_hipModuleLoadData = 171,
|
||||
HIP_API_ID_hipModuleLoadDataEx = 172,
|
||||
HIP_API_ID_hipModuleOccupancyMaxActiveBlocksPerMultiprocessor = 173,
|
||||
HIP_API_ID_hipModuleOccupancyMaxActiveBlocksPerMultiprocessorWithFlags = 174,
|
||||
HIP_API_ID_hipModuleOccupancyMaxPotentialBlockSize = 175,
|
||||
HIP_API_ID_hipModuleOccupancyMaxPotentialBlockSizeWithFlags = 176,
|
||||
HIP_API_ID_hipModuleUnload = 177,
|
||||
HIP_API_ID_hipOccupancyMaxActiveBlocksPerMultiprocessor = 178,
|
||||
HIP_API_ID_hipOccupancyMaxActiveBlocksPerMultiprocessorWithFlags = 179,
|
||||
HIP_API_ID_hipOccupancyMaxPotentialBlockSize = 180,
|
||||
HIP_API_ID_hipPeekAtLastError = 181,
|
||||
HIP_API_ID_hipPointerGetAttributes = 182,
|
||||
HIP_API_ID_hipProfilerStart = 183,
|
||||
HIP_API_ID_hipProfilerStop = 184,
|
||||
HIP_API_ID_RESERVED_185 = 185,
|
||||
HIP_API_ID_hipSetDevice = 186,
|
||||
HIP_API_ID_hipSetDeviceFlags = 187,
|
||||
HIP_API_ID_hipSetupArgument = 188,
|
||||
HIP_API_ID_hipSignalExternalSemaphoresAsync = 189,
|
||||
HIP_API_ID_hipStreamAddCallback = 190,
|
||||
HIP_API_ID_hipStreamAttachMemAsync = 191,
|
||||
HIP_API_ID_hipStreamCreate = 192,
|
||||
HIP_API_ID_hipStreamCreateWithFlags = 193,
|
||||
HIP_API_ID_hipStreamCreateWithPriority = 194,
|
||||
HIP_API_ID_hipStreamDestroy = 195,
|
||||
HIP_API_ID_hipStreamGetFlags = 196,
|
||||
HIP_API_ID_hipStreamGetPriority = 197,
|
||||
HIP_API_ID_hipStreamQuery = 198,
|
||||
HIP_API_ID_hipStreamSynchronize = 199,
|
||||
HIP_API_ID_hipStreamWaitEvent = 200,
|
||||
HIP_API_ID_hipStreamWaitValue32 = 201,
|
||||
HIP_API_ID_hipStreamWaitValue64 = 202,
|
||||
HIP_API_ID_hipStreamWriteValue32 = 203,
|
||||
HIP_API_ID_hipStreamWriteValue64 = 204,
|
||||
HIP_API_ID_hipWaitExternalSemaphoresAsync = 205,
|
||||
HIP_API_ID_hipCreateSurfaceObject = 206,
|
||||
HIP_API_ID_hipDestroySurfaceObject = 207,
|
||||
HIP_API_ID_hipGraphAddKernelNode = 208,
|
||||
HIP_API_ID_hipGraphAddMemcpyNode = 209,
|
||||
HIP_API_ID_hipGraphAddMemsetNode = 210,
|
||||
HIP_API_ID_hipGraphCreate = 211,
|
||||
HIP_API_ID_hipGraphDestroy = 212,
|
||||
HIP_API_ID_hipGraphExecDestroy = 213,
|
||||
HIP_API_ID_hipGraphInstantiate = 214,
|
||||
HIP_API_ID_hipGraphLaunch = 215,
|
||||
HIP_API_ID_hipMipmappedArrayCreate = 216,
|
||||
HIP_API_ID_hipMipmappedArrayDestroy = 217,
|
||||
HIP_API_ID_hipMipmappedArrayGetLevel = 218,
|
||||
HIP_API_ID_hipStreamBeginCapture = 219,
|
||||
HIP_API_ID_hipStreamEndCapture = 220,
|
||||
HIP_API_ID_hipTexRefGetAddress = 221,
|
||||
HIP_API_ID_hipTexRefGetFlags = 222,
|
||||
HIP_API_ID_hipTexRefGetFormat = 223,
|
||||
HIP_API_ID_hipTexRefGetMaxAnisotropy = 224,
|
||||
HIP_API_ID_hipTexRefGetMipMappedArray = 225,
|
||||
HIP_API_ID_hipTexRefGetMipmapLevelBias = 226,
|
||||
HIP_API_ID_hipTexRefGetMipmapLevelClamp = 227,
|
||||
HIP_API_ID_hipTexRefSetAddress = 228,
|
||||
HIP_API_ID_hipTexRefSetAddress2D = 229,
|
||||
HIP_API_ID_hipTexRefSetBorderColor = 230,
|
||||
HIP_API_ID_hipTexRefSetFormat = 231,
|
||||
HIP_API_ID_hipTexRefSetMaxAnisotropy = 232,
|
||||
HIP_API_ID_hipTexRefSetMipmapLevelClamp = 233,
|
||||
HIP_API_ID_hipTexRefSetMipmappedArray = 234,
|
||||
HIP_API_ID_hipGLGetDevices = 235,
|
||||
HIP_API_ID_hipGraphAddDependencies = 236,
|
||||
HIP_API_ID_hipGraphAddEmptyNode = 237,
|
||||
HIP_API_ID_hipGraphExecKernelNodeSetParams = 238,
|
||||
HIP_API_ID_hipGraphGetNodes = 239,
|
||||
HIP_API_ID_hipGraphGetRootNodes = 240,
|
||||
HIP_API_ID_hipGraphKernelNodeGetParams = 241,
|
||||
HIP_API_ID_hipGraphKernelNodeSetParams = 242,
|
||||
HIP_API_ID_hipGraphMemcpyNodeGetParams = 243,
|
||||
HIP_API_ID_hipGraphMemcpyNodeSetParams = 244,
|
||||
HIP_API_ID_hipGraphMemsetNodeGetParams = 245,
|
||||
HIP_API_ID_hipGraphMemsetNodeSetParams = 246,
|
||||
HIP_API_ID_hipGraphicsGLRegisterBuffer = 247,
|
||||
HIP_API_ID_hipGraphicsMapResources = 248,
|
||||
HIP_API_ID_hipGraphicsResourceGetMappedPointer = 249,
|
||||
HIP_API_ID_hipGraphicsUnmapResources = 250,
|
||||
HIP_API_ID_hipGraphicsUnregisterResource = 251,
|
||||
HIP_API_ID_hipGraphAddChildGraphNode = 252,
|
||||
HIP_API_ID_hipGraphAddEventRecordNode = 253,
|
||||
HIP_API_ID_hipGraphAddEventWaitNode = 254,
|
||||
HIP_API_ID_hipGraphAddHostNode = 255,
|
||||
HIP_API_ID_hipGraphAddMemcpyNode1D = 256,
|
||||
HIP_API_ID_hipGraphAddMemcpyNodeFromSymbol = 257,
|
||||
HIP_API_ID_hipGraphAddMemcpyNodeToSymbol = 258,
|
||||
HIP_API_ID_hipGraphChildGraphNodeGetGraph = 259,
|
||||
HIP_API_ID_hipGraphClone = 260,
|
||||
HIP_API_ID_hipGraphDestroyNode = 261,
|
||||
HIP_API_ID_hipGraphEventRecordNodeGetEvent = 262,
|
||||
HIP_API_ID_hipGraphEventRecordNodeSetEvent = 263,
|
||||
HIP_API_ID_hipGraphEventWaitNodeGetEvent = 264,
|
||||
HIP_API_ID_hipGraphEventWaitNodeSetEvent = 265,
|
||||
HIP_API_ID_hipGraphExecChildGraphNodeSetParams = 266,
|
||||
HIP_API_ID_hipGraphExecEventRecordNodeSetEvent = 267,
|
||||
HIP_API_ID_hipGraphExecEventWaitNodeSetEvent = 268,
|
||||
HIP_API_ID_hipGraphExecHostNodeSetParams = 269,
|
||||
HIP_API_ID_hipGraphExecMemcpyNodeSetParams = 270,
|
||||
HIP_API_ID_hipGraphExecMemcpyNodeSetParams1D = 271,
|
||||
HIP_API_ID_hipGraphExecMemcpyNodeSetParamsFromSymbol = 272,
|
||||
HIP_API_ID_hipGraphExecMemcpyNodeSetParamsToSymbol = 273,
|
||||
HIP_API_ID_hipGraphExecMemsetNodeSetParams = 274,
|
||||
HIP_API_ID_hipGraphExecUpdate = 275,
|
||||
HIP_API_ID_hipGraphGetEdges = 276,
|
||||
HIP_API_ID_hipGraphHostNodeGetParams = 277,
|
||||
HIP_API_ID_hipGraphHostNodeSetParams = 278,
|
||||
HIP_API_ID_hipGraphInstantiateWithFlags = 279,
|
||||
HIP_API_ID_hipGraphMemcpyNodeSetParams1D = 280,
|
||||
HIP_API_ID_hipGraphMemcpyNodeSetParamsFromSymbol = 281,
|
||||
HIP_API_ID_hipGraphMemcpyNodeSetParamsToSymbol = 282,
|
||||
HIP_API_ID_hipGraphNodeFindInClone = 283,
|
||||
HIP_API_ID_hipGraphNodeGetDependencies = 284,
|
||||
HIP_API_ID_hipGraphNodeGetDependentNodes = 285,
|
||||
HIP_API_ID_hipGraphNodeGetType = 286,
|
||||
HIP_API_ID_hipGraphRemoveDependencies = 287,
|
||||
HIP_API_ID_hipStreamGetCaptureInfo = 288,
|
||||
HIP_API_ID_hipStreamGetCaptureInfo_v2 = 289,
|
||||
HIP_API_ID_hipStreamIsCapturing = 290,
|
||||
HIP_API_ID_hipStreamUpdateCaptureDependencies = 291,
|
||||
HIP_API_ID_hipDrvPointerGetAttributes = 292,
|
||||
HIP_API_ID_hipGraphicsGLRegisterImage = 293,
|
||||
HIP_API_ID_hipGraphicsSubResourceGetMappedArray = 294,
|
||||
HIP_API_ID_hipPointerGetAttribute = 295,
|
||||
HIP_API_ID_RESERVED_296 = 296,
|
||||
HIP_API_ID_hipThreadExchangeStreamCaptureMode = 297,
|
||||
HIP_API_ID_hipDeviceGetUuid = 298,
|
||||
HIP_API_ID_hipGetChannelDesc = 299,
|
||||
HIP_API_ID_hipGraphKernelNodeGetAttribute = 300,
|
||||
HIP_API_ID_hipGraphKernelNodeSetAttribute = 301,
|
||||
HIP_API_ID_hipLaunchHostFunc = 302,
|
||||
HIP_API_ID_hipDeviceGetDefaultMemPool = 303,
|
||||
HIP_API_ID_hipDeviceGetMemPool = 304,
|
||||
HIP_API_ID_hipDeviceSetMemPool = 305,
|
||||
HIP_API_ID_hipFreeAsync = 306,
|
||||
HIP_API_ID_hipMallocAsync = 307,
|
||||
HIP_API_ID_hipMallocFromPoolAsync = 308,
|
||||
HIP_API_ID_hipMemPoolCreate = 309,
|
||||
HIP_API_ID_hipMemPoolDestroy = 310,
|
||||
HIP_API_ID_hipMemPoolExportPointer = 311,
|
||||
HIP_API_ID_hipMemPoolExportToShareableHandle = 312,
|
||||
HIP_API_ID_hipMemPoolGetAccess = 313,
|
||||
HIP_API_ID_hipMemPoolGetAttribute = 314,
|
||||
HIP_API_ID_hipMemPoolImportFromShareableHandle = 315,
|
||||
HIP_API_ID_hipMemPoolImportPointer = 316,
|
||||
HIP_API_ID_hipMemPoolSetAccess = 317,
|
||||
HIP_API_ID_hipMemPoolSetAttribute = 318,
|
||||
HIP_API_ID_hipMemPoolTrimTo = 319,
|
||||
HIP_API_ID_hipMemAddressFree = 320,
|
||||
HIP_API_ID_hipMemAddressReserve = 321,
|
||||
HIP_API_ID_hipMemCreate = 322,
|
||||
HIP_API_ID_hipMemExportToShareableHandle = 323,
|
||||
HIP_API_ID_hipMemGetAccess = 324,
|
||||
HIP_API_ID_hipMemGetAllocationGranularity = 325,
|
||||
HIP_API_ID_hipMemGetAllocationPropertiesFromHandle = 326,
|
||||
HIP_API_ID_hipMemImportFromShareableHandle = 327,
|
||||
HIP_API_ID_hipMemMap = 328,
|
||||
HIP_API_ID_hipMemMapArrayAsync = 329,
|
||||
HIP_API_ID_hipMemRelease = 330,
|
||||
HIP_API_ID_hipMemRetainAllocationHandle = 331,
|
||||
HIP_API_ID_hipMemSetAccess = 332,
|
||||
HIP_API_ID_hipMemUnmap = 333,
|
||||
HIP_API_ID_hipDeviceSetGraphMemAttribute = 334,
|
||||
HIP_API_ID_hipDeviceGetGraphMemAttribute = 335,
|
||||
HIP_API_ID_hipDeviceGraphMemTrim = 336,
|
||||
HIP_API_ID_hipDeviceSetLimit = 337,
|
||||
HIP_API_ID_hipTexRefSetArray = 338,
|
||||
HIP_API_ID_hipTexRefSetFlags = 339,
|
||||
HIP_API_ID_hipTexRefSetMipmapLevelBias = 340,
|
||||
HIP_API_ID_hipDriverGetVersion = 341,
|
||||
HIP_API_ID_hipGraphUpload = 342,
|
||||
HIP_API_ID_hipRuntimeGetVersion = 343,
|
||||
HIP_API_ID_hipUserObjectCreate = 344,
|
||||
HIP_API_ID_hipUserObjectRelease = 345,
|
||||
HIP_API_ID_hipUserObjectRetain = 346,
|
||||
HIP_API_ID_hipGraphRetainUserObject = 347,
|
||||
HIP_API_ID_hipGraphReleaseUserObject = 348,
|
||||
HIP_API_ID_hipCreateSurfaceObject = 8,
|
||||
HIP_API_ID_hipCtxCreate = 9,
|
||||
HIP_API_ID_hipCtxDestroy = 10,
|
||||
HIP_API_ID_hipCtxDisablePeerAccess = 11,
|
||||
HIP_API_ID_hipCtxEnablePeerAccess = 12,
|
||||
HIP_API_ID_hipCtxGetApiVersion = 13,
|
||||
HIP_API_ID_hipCtxGetCacheConfig = 14,
|
||||
HIP_API_ID_hipCtxGetCurrent = 15,
|
||||
HIP_API_ID_hipCtxGetDevice = 16,
|
||||
HIP_API_ID_hipCtxGetFlags = 17,
|
||||
HIP_API_ID_hipCtxGetSharedMemConfig = 18,
|
||||
HIP_API_ID_hipCtxPopCurrent = 19,
|
||||
HIP_API_ID_hipCtxPushCurrent = 20,
|
||||
HIP_API_ID_hipCtxSetCacheConfig = 21,
|
||||
HIP_API_ID_hipCtxSetCurrent = 22,
|
||||
HIP_API_ID_hipCtxSetSharedMemConfig = 23,
|
||||
HIP_API_ID_hipCtxSynchronize = 24,
|
||||
HIP_API_ID_hipDestroyExternalMemory = 25,
|
||||
HIP_API_ID_hipDestroyExternalSemaphore = 26,
|
||||
HIP_API_ID_hipDestroySurfaceObject = 27,
|
||||
HIP_API_ID_hipDeviceCanAccessPeer = 28,
|
||||
HIP_API_ID_hipDeviceComputeCapability = 29,
|
||||
HIP_API_ID_hipDeviceDisablePeerAccess = 30,
|
||||
HIP_API_ID_hipDeviceEnablePeerAccess = 31,
|
||||
HIP_API_ID_hipDeviceGet = 32,
|
||||
HIP_API_ID_hipDeviceGetAttribute = 33,
|
||||
HIP_API_ID_hipDeviceGetByPCIBusId = 34,
|
||||
HIP_API_ID_hipDeviceGetCacheConfig = 35,
|
||||
HIP_API_ID_hipDeviceGetDefaultMemPool = 36,
|
||||
HIP_API_ID_hipDeviceGetGraphMemAttribute = 37,
|
||||
HIP_API_ID_hipDeviceGetLimit = 38,
|
||||
HIP_API_ID_hipDeviceGetMemPool = 39,
|
||||
HIP_API_ID_hipDeviceGetName = 40,
|
||||
HIP_API_ID_hipDeviceGetP2PAttribute = 41,
|
||||
HIP_API_ID_hipDeviceGetPCIBusId = 42,
|
||||
HIP_API_ID_hipDeviceGetSharedMemConfig = 43,
|
||||
HIP_API_ID_hipDeviceGetStreamPriorityRange = 44,
|
||||
HIP_API_ID_hipDeviceGetUuid = 45,
|
||||
HIP_API_ID_hipDeviceGraphMemTrim = 46,
|
||||
HIP_API_ID_hipDevicePrimaryCtxGetState = 47,
|
||||
HIP_API_ID_hipDevicePrimaryCtxRelease = 48,
|
||||
HIP_API_ID_hipDevicePrimaryCtxReset = 49,
|
||||
HIP_API_ID_hipDevicePrimaryCtxRetain = 50,
|
||||
HIP_API_ID_hipDevicePrimaryCtxSetFlags = 51,
|
||||
HIP_API_ID_hipDeviceReset = 52,
|
||||
HIP_API_ID_hipDeviceSetCacheConfig = 53,
|
||||
HIP_API_ID_hipDeviceSetGraphMemAttribute = 54,
|
||||
HIP_API_ID_hipDeviceSetLimit = 55,
|
||||
HIP_API_ID_hipDeviceSetMemPool = 56,
|
||||
HIP_API_ID_hipDeviceSetSharedMemConfig = 57,
|
||||
HIP_API_ID_hipDeviceSynchronize = 58,
|
||||
HIP_API_ID_hipDeviceTotalMem = 59,
|
||||
HIP_API_ID_hipDriverGetVersion = 60,
|
||||
HIP_API_ID_hipDrvMemcpy2DUnaligned = 61,
|
||||
HIP_API_ID_hipDrvMemcpy3D = 62,
|
||||
HIP_API_ID_hipDrvMemcpy3DAsync = 63,
|
||||
HIP_API_ID_hipDrvPointerGetAttributes = 64,
|
||||
HIP_API_ID_hipEventCreate = 65,
|
||||
HIP_API_ID_hipEventCreateWithFlags = 66,
|
||||
HIP_API_ID_hipEventDestroy = 67,
|
||||
HIP_API_ID_hipEventElapsedTime = 68,
|
||||
HIP_API_ID_hipEventQuery = 69,
|
||||
HIP_API_ID_hipEventRecord = 70,
|
||||
HIP_API_ID_hipEventSynchronize = 71,
|
||||
HIP_API_ID_hipExtGetLinkTypeAndHopCount = 72,
|
||||
HIP_API_ID_hipExtLaunchKernel = 73,
|
||||
HIP_API_ID_hipExtLaunchMultiKernelMultiDevice = 74,
|
||||
HIP_API_ID_hipExtMallocWithFlags = 75,
|
||||
HIP_API_ID_hipExtModuleLaunchKernel = 76,
|
||||
HIP_API_ID_hipExtStreamCreateWithCUMask = 77,
|
||||
HIP_API_ID_hipExtStreamGetCUMask = 78,
|
||||
HIP_API_ID_hipExternalMemoryGetMappedBuffer = 79,
|
||||
HIP_API_ID_hipFree = 80,
|
||||
HIP_API_ID_hipFreeArray = 81,
|
||||
HIP_API_ID_hipFreeAsync = 82,
|
||||
HIP_API_ID_hipFreeHost = 83,
|
||||
HIP_API_ID_hipFreeMipmappedArray = 84,
|
||||
HIP_API_ID_hipFuncGetAttribute = 85,
|
||||
HIP_API_ID_hipFuncGetAttributes = 86,
|
||||
HIP_API_ID_hipFuncSetAttribute = 87,
|
||||
HIP_API_ID_hipFuncSetCacheConfig = 88,
|
||||
HIP_API_ID_hipFuncSetSharedMemConfig = 89,
|
||||
HIP_API_ID_hipGLGetDevices = 90,
|
||||
HIP_API_ID_hipGetChannelDesc = 91,
|
||||
HIP_API_ID_hipGetDevice = 92,
|
||||
HIP_API_ID_hipGetDeviceCount = 93,
|
||||
HIP_API_ID_hipGetDeviceFlags = 94,
|
||||
HIP_API_ID_hipGetDeviceProperties = 95,
|
||||
HIP_API_ID_hipGetErrorString = 96,
|
||||
HIP_API_ID_hipGetLastError = 97,
|
||||
HIP_API_ID_hipGetMipmappedArrayLevel = 98,
|
||||
HIP_API_ID_hipGetSymbolAddress = 99,
|
||||
HIP_API_ID_hipGetSymbolSize = 100,
|
||||
HIP_API_ID_hipGraphAddChildGraphNode = 101,
|
||||
HIP_API_ID_hipGraphAddDependencies = 102,
|
||||
HIP_API_ID_hipGraphAddEmptyNode = 103,
|
||||
HIP_API_ID_hipGraphAddEventRecordNode = 104,
|
||||
HIP_API_ID_hipGraphAddEventWaitNode = 105,
|
||||
HIP_API_ID_hipGraphAddHostNode = 106,
|
||||
HIP_API_ID_hipGraphAddKernelNode = 107,
|
||||
HIP_API_ID_hipGraphAddMemcpyNode = 108,
|
||||
HIP_API_ID_hipGraphAddMemcpyNode1D = 109,
|
||||
HIP_API_ID_hipGraphAddMemcpyNodeFromSymbol = 110,
|
||||
HIP_API_ID_hipGraphAddMemcpyNodeToSymbol = 111,
|
||||
HIP_API_ID_hipGraphAddMemsetNode = 112,
|
||||
HIP_API_ID_hipGraphChildGraphNodeGetGraph = 113,
|
||||
HIP_API_ID_hipGraphClone = 114,
|
||||
HIP_API_ID_hipGraphCreate = 115,
|
||||
HIP_API_ID_hipGraphDestroy = 116,
|
||||
HIP_API_ID_hipGraphDestroyNode = 117,
|
||||
HIP_API_ID_hipGraphEventRecordNodeGetEvent = 118,
|
||||
HIP_API_ID_hipGraphEventRecordNodeSetEvent = 119,
|
||||
HIP_API_ID_hipGraphEventWaitNodeGetEvent = 120,
|
||||
HIP_API_ID_hipGraphEventWaitNodeSetEvent = 121,
|
||||
HIP_API_ID_hipGraphExecChildGraphNodeSetParams = 122,
|
||||
HIP_API_ID_hipGraphExecDestroy = 123,
|
||||
HIP_API_ID_hipGraphExecEventRecordNodeSetEvent = 124,
|
||||
HIP_API_ID_hipGraphExecEventWaitNodeSetEvent = 125,
|
||||
HIP_API_ID_hipGraphExecHostNodeSetParams = 126,
|
||||
HIP_API_ID_hipGraphExecKernelNodeSetParams = 127,
|
||||
HIP_API_ID_hipGraphExecMemcpyNodeSetParams = 128,
|
||||
HIP_API_ID_hipGraphExecMemcpyNodeSetParams1D = 129,
|
||||
HIP_API_ID_hipGraphExecMemcpyNodeSetParamsFromSymbol = 130,
|
||||
HIP_API_ID_hipGraphExecMemcpyNodeSetParamsToSymbol = 131,
|
||||
HIP_API_ID_hipGraphExecMemsetNodeSetParams = 132,
|
||||
HIP_API_ID_hipGraphExecUpdate = 133,
|
||||
HIP_API_ID_hipGraphGetEdges = 134,
|
||||
HIP_API_ID_hipGraphGetNodes = 135,
|
||||
HIP_API_ID_hipGraphGetRootNodes = 136,
|
||||
HIP_API_ID_hipGraphHostNodeGetParams = 137,
|
||||
HIP_API_ID_hipGraphHostNodeSetParams = 138,
|
||||
HIP_API_ID_hipGraphInstantiate = 139,
|
||||
HIP_API_ID_hipGraphInstantiateWithFlags = 140,
|
||||
HIP_API_ID_hipGraphKernelNodeGetAttribute = 141,
|
||||
HIP_API_ID_hipGraphKernelNodeGetParams = 142,
|
||||
HIP_API_ID_hipGraphKernelNodeSetAttribute = 143,
|
||||
HIP_API_ID_hipGraphKernelNodeSetParams = 144,
|
||||
HIP_API_ID_hipGraphLaunch = 145,
|
||||
HIP_API_ID_hipGraphMemcpyNodeGetParams = 146,
|
||||
HIP_API_ID_hipGraphMemcpyNodeSetParams = 147,
|
||||
HIP_API_ID_hipGraphMemcpyNodeSetParams1D = 148,
|
||||
HIP_API_ID_hipGraphMemcpyNodeSetParamsFromSymbol = 149,
|
||||
HIP_API_ID_hipGraphMemcpyNodeSetParamsToSymbol = 150,
|
||||
HIP_API_ID_hipGraphMemsetNodeGetParams = 151,
|
||||
HIP_API_ID_hipGraphMemsetNodeSetParams = 152,
|
||||
HIP_API_ID_hipGraphNodeFindInClone = 153,
|
||||
HIP_API_ID_hipGraphNodeGetDependencies = 154,
|
||||
HIP_API_ID_hipGraphNodeGetDependentNodes = 155,
|
||||
HIP_API_ID_hipGraphNodeGetType = 156,
|
||||
HIP_API_ID_hipGraphReleaseUserObject = 157,
|
||||
HIP_API_ID_hipGraphRemoveDependencies = 158,
|
||||
HIP_API_ID_hipGraphRetainUserObject = 159,
|
||||
HIP_API_ID_hipGraphUpload = 160,
|
||||
HIP_API_ID_hipGraphicsGLRegisterBuffer = 161,
|
||||
HIP_API_ID_hipGraphicsGLRegisterImage = 162,
|
||||
HIP_API_ID_hipGraphicsMapResources = 163,
|
||||
HIP_API_ID_hipGraphicsResourceGetMappedPointer = 164,
|
||||
HIP_API_ID_hipGraphicsSubResourceGetMappedArray = 165,
|
||||
HIP_API_ID_hipGraphicsUnmapResources = 166,
|
||||
HIP_API_ID_hipGraphicsUnregisterResource = 167,
|
||||
HIP_API_ID_hipHccModuleLaunchKernel = 168,
|
||||
HIP_API_ID_hipHostAlloc = 169,
|
||||
HIP_API_ID_hipHostFree = 170,
|
||||
HIP_API_ID_hipHostGetDevicePointer = 171,
|
||||
HIP_API_ID_hipHostGetFlags = 172,
|
||||
HIP_API_ID_hipHostMalloc = 173,
|
||||
HIP_API_ID_hipHostRegister = 174,
|
||||
HIP_API_ID_hipHostUnregister = 175,
|
||||
HIP_API_ID_hipImportExternalMemory = 176,
|
||||
HIP_API_ID_hipImportExternalSemaphore = 177,
|
||||
HIP_API_ID_hipInit = 178,
|
||||
HIP_API_ID_hipIpcCloseMemHandle = 179,
|
||||
HIP_API_ID_hipIpcGetEventHandle = 180,
|
||||
HIP_API_ID_hipIpcGetMemHandle = 181,
|
||||
HIP_API_ID_hipIpcOpenEventHandle = 182,
|
||||
HIP_API_ID_hipIpcOpenMemHandle = 183,
|
||||
HIP_API_ID_hipLaunchByPtr = 184,
|
||||
HIP_API_ID_hipLaunchCooperativeKernel = 185,
|
||||
HIP_API_ID_hipLaunchCooperativeKernelMultiDevice = 186,
|
||||
HIP_API_ID_hipLaunchHostFunc = 187,
|
||||
HIP_API_ID_hipLaunchKernel = 188,
|
||||
HIP_API_ID_hipMalloc = 189,
|
||||
HIP_API_ID_hipMalloc3D = 190,
|
||||
HIP_API_ID_hipMalloc3DArray = 191,
|
||||
HIP_API_ID_hipMallocArray = 192,
|
||||
HIP_API_ID_hipMallocAsync = 193,
|
||||
HIP_API_ID_hipMallocFromPoolAsync = 194,
|
||||
HIP_API_ID_hipMallocHost = 195,
|
||||
HIP_API_ID_hipMallocManaged = 196,
|
||||
HIP_API_ID_hipMallocMipmappedArray = 197,
|
||||
HIP_API_ID_hipMallocPitch = 198,
|
||||
HIP_API_ID_hipMemAddressFree = 199,
|
||||
HIP_API_ID_hipMemAddressReserve = 200,
|
||||
HIP_API_ID_hipMemAdvise = 201,
|
||||
HIP_API_ID_hipMemAllocHost = 202,
|
||||
HIP_API_ID_hipMemAllocPitch = 203,
|
||||
HIP_API_ID_hipMemCreate = 204,
|
||||
HIP_API_ID_hipMemExportToShareableHandle = 205,
|
||||
HIP_API_ID_hipMemGetAccess = 206,
|
||||
HIP_API_ID_hipMemGetAddressRange = 207,
|
||||
HIP_API_ID_hipMemGetAllocationGranularity = 208,
|
||||
HIP_API_ID_hipMemGetAllocationPropertiesFromHandle = 209,
|
||||
HIP_API_ID_hipMemGetInfo = 210,
|
||||
HIP_API_ID_hipMemImportFromShareableHandle = 211,
|
||||
HIP_API_ID_hipMemMap = 212,
|
||||
HIP_API_ID_hipMemMapArrayAsync = 213,
|
||||
HIP_API_ID_hipMemPoolCreate = 214,
|
||||
HIP_API_ID_hipMemPoolDestroy = 215,
|
||||
HIP_API_ID_hipMemPoolExportPointer = 216,
|
||||
HIP_API_ID_hipMemPoolExportToShareableHandle = 217,
|
||||
HIP_API_ID_hipMemPoolGetAccess = 218,
|
||||
HIP_API_ID_hipMemPoolGetAttribute = 219,
|
||||
HIP_API_ID_hipMemPoolImportFromShareableHandle = 220,
|
||||
HIP_API_ID_hipMemPoolImportPointer = 221,
|
||||
HIP_API_ID_hipMemPoolSetAccess = 222,
|
||||
HIP_API_ID_hipMemPoolSetAttribute = 223,
|
||||
HIP_API_ID_hipMemPoolTrimTo = 224,
|
||||
HIP_API_ID_hipMemPrefetchAsync = 225,
|
||||
HIP_API_ID_hipMemPtrGetInfo = 226,
|
||||
HIP_API_ID_hipMemRangeGetAttribute = 227,
|
||||
HIP_API_ID_hipMemRangeGetAttributes = 228,
|
||||
HIP_API_ID_hipMemRelease = 229,
|
||||
HIP_API_ID_hipMemRetainAllocationHandle = 230,
|
||||
HIP_API_ID_hipMemSetAccess = 231,
|
||||
HIP_API_ID_hipMemUnmap = 232,
|
||||
HIP_API_ID_hipMemcpy = 233,
|
||||
HIP_API_ID_hipMemcpy2D = 234,
|
||||
HIP_API_ID_hipMemcpy2DAsync = 235,
|
||||
HIP_API_ID_hipMemcpy2DFromArray = 236,
|
||||
HIP_API_ID_hipMemcpy2DFromArrayAsync = 237,
|
||||
HIP_API_ID_hipMemcpy2DToArray = 238,
|
||||
HIP_API_ID_hipMemcpy2DToArrayAsync = 239,
|
||||
HIP_API_ID_hipMemcpy3D = 240,
|
||||
HIP_API_ID_hipMemcpy3DAsync = 241,
|
||||
HIP_API_ID_hipMemcpyAsync = 242,
|
||||
HIP_API_ID_hipMemcpyAtoH = 243,
|
||||
HIP_API_ID_hipMemcpyDtoD = 244,
|
||||
HIP_API_ID_hipMemcpyDtoDAsync = 245,
|
||||
HIP_API_ID_hipMemcpyDtoH = 246,
|
||||
HIP_API_ID_hipMemcpyDtoHAsync = 247,
|
||||
HIP_API_ID_hipMemcpyFromArray = 248,
|
||||
HIP_API_ID_hipMemcpyFromSymbol = 249,
|
||||
HIP_API_ID_hipMemcpyFromSymbolAsync = 250,
|
||||
HIP_API_ID_hipMemcpyHtoA = 251,
|
||||
HIP_API_ID_hipMemcpyHtoD = 252,
|
||||
HIP_API_ID_hipMemcpyHtoDAsync = 253,
|
||||
HIP_API_ID_hipMemcpyParam2D = 254,
|
||||
HIP_API_ID_hipMemcpyParam2DAsync = 255,
|
||||
HIP_API_ID_hipMemcpyPeer = 256,
|
||||
HIP_API_ID_hipMemcpyPeerAsync = 257,
|
||||
HIP_API_ID_hipMemcpyToArray = 258,
|
||||
HIP_API_ID_hipMemcpyToSymbol = 259,
|
||||
HIP_API_ID_hipMemcpyToSymbolAsync = 260,
|
||||
HIP_API_ID_hipMemcpyWithStream = 261,
|
||||
HIP_API_ID_hipMemset = 262,
|
||||
HIP_API_ID_hipMemset2D = 263,
|
||||
HIP_API_ID_hipMemset2DAsync = 264,
|
||||
HIP_API_ID_hipMemset3D = 265,
|
||||
HIP_API_ID_hipMemset3DAsync = 266,
|
||||
HIP_API_ID_hipMemsetAsync = 267,
|
||||
HIP_API_ID_hipMemsetD16 = 268,
|
||||
HIP_API_ID_hipMemsetD16Async = 269,
|
||||
HIP_API_ID_hipMemsetD32 = 270,
|
||||
HIP_API_ID_hipMemsetD32Async = 271,
|
||||
HIP_API_ID_hipMemsetD8 = 272,
|
||||
HIP_API_ID_hipMemsetD8Async = 273,
|
||||
HIP_API_ID_hipMipmappedArrayCreate = 274,
|
||||
HIP_API_ID_hipMipmappedArrayDestroy = 275,
|
||||
HIP_API_ID_hipMipmappedArrayGetLevel = 276,
|
||||
HIP_API_ID_hipModuleGetFunction = 277,
|
||||
HIP_API_ID_hipModuleGetGlobal = 278,
|
||||
HIP_API_ID_hipModuleGetTexRef = 279,
|
||||
HIP_API_ID_hipModuleLaunchKernel = 280,
|
||||
HIP_API_ID_hipModuleLoad = 281,
|
||||
HIP_API_ID_hipModuleLoadData = 282,
|
||||
HIP_API_ID_hipModuleLoadDataEx = 283,
|
||||
HIP_API_ID_hipModuleOccupancyMaxActiveBlocksPerMultiprocessor = 284,
|
||||
HIP_API_ID_hipModuleOccupancyMaxActiveBlocksPerMultiprocessorWithFlags = 285,
|
||||
HIP_API_ID_hipModuleOccupancyMaxPotentialBlockSize = 286,
|
||||
HIP_API_ID_hipModuleOccupancyMaxPotentialBlockSizeWithFlags = 287,
|
||||
HIP_API_ID_hipModuleUnload = 288,
|
||||
HIP_API_ID_hipOccupancyMaxActiveBlocksPerMultiprocessor = 289,
|
||||
HIP_API_ID_hipOccupancyMaxActiveBlocksPerMultiprocessorWithFlags = 290,
|
||||
HIP_API_ID_hipOccupancyMaxPotentialBlockSize = 291,
|
||||
HIP_API_ID_hipPeekAtLastError = 292,
|
||||
HIP_API_ID_hipPointerGetAttribute = 293,
|
||||
HIP_API_ID_hipPointerGetAttributes = 294,
|
||||
HIP_API_ID_hipProfilerStart = 295,
|
||||
HIP_API_ID_hipProfilerStop = 296,
|
||||
HIP_API_ID_hipRegisterActivityCallback = 297,
|
||||
HIP_API_ID_hipRegisterApiCallback = 298,
|
||||
HIP_API_ID_hipRemoveActivityCallback = 299,
|
||||
HIP_API_ID_hipRemoveApiCallback = 300,
|
||||
HIP_API_ID_hipRuntimeGetVersion = 301,
|
||||
HIP_API_ID_hipSetDevice = 302,
|
||||
HIP_API_ID_hipSetDeviceFlags = 303,
|
||||
HIP_API_ID_hipSetupArgument = 304,
|
||||
HIP_API_ID_hipSignalExternalSemaphoresAsync = 305,
|
||||
HIP_API_ID_hipStreamAddCallback = 306,
|
||||
HIP_API_ID_hipStreamAttachMemAsync = 307,
|
||||
HIP_API_ID_hipStreamBeginCapture = 308,
|
||||
HIP_API_ID_hipStreamCreate = 309,
|
||||
HIP_API_ID_hipStreamCreateWithFlags = 310,
|
||||
HIP_API_ID_hipStreamCreateWithPriority = 311,
|
||||
HIP_API_ID_hipStreamDestroy = 312,
|
||||
HIP_API_ID_hipStreamEndCapture = 313,
|
||||
HIP_API_ID_hipStreamGetCaptureInfo = 314,
|
||||
HIP_API_ID_hipStreamGetCaptureInfo_v2 = 315,
|
||||
HIP_API_ID_hipStreamGetFlags = 316,
|
||||
HIP_API_ID_hipStreamGetPriority = 317,
|
||||
HIP_API_ID_hipStreamIsCapturing = 318,
|
||||
HIP_API_ID_hipStreamQuery = 319,
|
||||
HIP_API_ID_hipStreamSynchronize = 320,
|
||||
HIP_API_ID_hipStreamUpdateCaptureDependencies = 321,
|
||||
HIP_API_ID_hipStreamWaitEvent = 322,
|
||||
HIP_API_ID_hipStreamWaitValue32 = 323,
|
||||
HIP_API_ID_hipStreamWaitValue64 = 324,
|
||||
HIP_API_ID_hipStreamWriteValue32 = 325,
|
||||
HIP_API_ID_hipStreamWriteValue64 = 326,
|
||||
HIP_API_ID_hipTexRefGetAddress = 327,
|
||||
HIP_API_ID_hipTexRefGetFlags = 328,
|
||||
HIP_API_ID_hipTexRefGetFormat = 329,
|
||||
HIP_API_ID_hipTexRefGetMaxAnisotropy = 330,
|
||||
HIP_API_ID_hipTexRefGetMipMappedArray = 331,
|
||||
HIP_API_ID_hipTexRefGetMipmapLevelBias = 332,
|
||||
HIP_API_ID_hipTexRefGetMipmapLevelClamp = 333,
|
||||
HIP_API_ID_hipTexRefSetAddress = 334,
|
||||
HIP_API_ID_hipTexRefSetAddress2D = 335,
|
||||
HIP_API_ID_hipTexRefSetArray = 336,
|
||||
HIP_API_ID_hipTexRefSetBorderColor = 337,
|
||||
HIP_API_ID_hipTexRefSetFlags = 338,
|
||||
HIP_API_ID_hipTexRefSetFormat = 339,
|
||||
HIP_API_ID_hipTexRefSetMaxAnisotropy = 340,
|
||||
HIP_API_ID_hipTexRefSetMipmapLevelBias = 341,
|
||||
HIP_API_ID_hipTexRefSetMipmapLevelClamp = 342,
|
||||
HIP_API_ID_hipTexRefSetMipmappedArray = 343,
|
||||
HIP_API_ID_hipThreadExchangeStreamCaptureMode = 344,
|
||||
HIP_API_ID_hipUserObjectCreate = 345,
|
||||
HIP_API_ID_hipUserObjectRelease = 346,
|
||||
HIP_API_ID_hipUserObjectRetain = 347,
|
||||
HIP_API_ID_hipWaitExternalSemaphoresAsync = 348,
|
||||
HIP_API_ID_LAST = 348,
|
||||
|
||||
HIP_API_ID_hipArray3DGetDescriptor = HIP_API_ID_NONE,
|
||||
@@ -702,6 +702,10 @@ static inline const char* hip_api_name(const uint32_t id) {
|
||||
case HIP_API_ID_hipPointerGetAttributes: return "hipPointerGetAttributes";
|
||||
case HIP_API_ID_hipProfilerStart: return "hipProfilerStart";
|
||||
case HIP_API_ID_hipProfilerStop: return "hipProfilerStop";
|
||||
case HIP_API_ID_hipRegisterActivityCallback: return "hipRegisterActivityCallback";
|
||||
case HIP_API_ID_hipRegisterApiCallback: return "hipRegisterApiCallback";
|
||||
case HIP_API_ID_hipRemoveActivityCallback: return "hipRemoveActivityCallback";
|
||||
case HIP_API_ID_hipRemoveApiCallback: return "hipRemoveApiCallback";
|
||||
case HIP_API_ID_hipRuntimeGetVersion: return "hipRuntimeGetVersion";
|
||||
case HIP_API_ID_hipSetDevice: return "hipSetDevice";
|
||||
case HIP_API_ID_hipSetDeviceFlags: return "hipSetDeviceFlags";
|
||||
@@ -1053,6 +1057,10 @@ static inline uint32_t hipApiIdByName(const char* name) {
|
||||
if (strcmp("hipPointerGetAttributes", name) == 0) return HIP_API_ID_hipPointerGetAttributes;
|
||||
if (strcmp("hipProfilerStart", name) == 0) return HIP_API_ID_hipProfilerStart;
|
||||
if (strcmp("hipProfilerStop", name) == 0) return HIP_API_ID_hipProfilerStop;
|
||||
if (strcmp("hipRegisterActivityCallback", name) == 0) return HIP_API_ID_hipRegisterActivityCallback;
|
||||
if (strcmp("hipRegisterApiCallback", name) == 0) return HIP_API_ID_hipRegisterApiCallback;
|
||||
if (strcmp("hipRemoveActivityCallback", name) == 0) return HIP_API_ID_hipRemoveActivityCallback;
|
||||
if (strcmp("hipRemoveApiCallback", name) == 0) return HIP_API_ID_hipRemoveApiCallback;
|
||||
if (strcmp("hipRuntimeGetVersion", name) == 0) return HIP_API_ID_hipRuntimeGetVersion;
|
||||
if (strcmp("hipSetDevice", name) == 0) return HIP_API_ID_hipSetDevice;
|
||||
if (strcmp("hipSetDeviceFlags", name) == 0) return HIP_API_ID_hipSetDeviceFlags;
|
||||
@@ -2845,6 +2853,22 @@ typedef struct hip_api_data_s {
|
||||
hipPointerAttribute_t attributes__val;
|
||||
const void* ptr;
|
||||
} hipPointerGetAttributes;
|
||||
struct {
|
||||
unsigned int id;
|
||||
void* fun;
|
||||
void* arg;
|
||||
} hipRegisterActivityCallback;
|
||||
struct {
|
||||
unsigned int id;
|
||||
void* fun;
|
||||
void* arg;
|
||||
} hipRegisterApiCallback;
|
||||
struct {
|
||||
unsigned int id;
|
||||
} hipRemoveActivityCallback;
|
||||
struct {
|
||||
unsigned int id;
|
||||
} hipRemoveApiCallback;
|
||||
struct {
|
||||
int* runtimeVersion;
|
||||
int runtimeVersion__val;
|
||||
@@ -4919,6 +4943,18 @@ typedef struct hip_api_data_s {
|
||||
// hipProfilerStop[]
|
||||
#define INIT_hipProfilerStop_CB_ARGS_DATA(cb_data) { \
|
||||
};
|
||||
// hipRegisterActivityCallback[('unsigned int', 'id'), ('void*', 'fun'), ('void*', 'arg')]
|
||||
#define INIT_hipRegisterActivityCallback_CB_ARGS_DATA(cb_data) { \
|
||||
};
|
||||
// hipRegisterApiCallback[('unsigned int', 'id'), ('void*', 'fun'), ('void*', 'arg')]
|
||||
#define INIT_hipRegisterApiCallback_CB_ARGS_DATA(cb_data) { \
|
||||
};
|
||||
// hipRemoveActivityCallback[('unsigned int', 'id')]
|
||||
#define INIT_hipRemoveActivityCallback_CB_ARGS_DATA(cb_data) { \
|
||||
};
|
||||
// hipRemoveApiCallback[('unsigned int', 'id')]
|
||||
#define INIT_hipRemoveApiCallback_CB_ARGS_DATA(cb_data) { \
|
||||
};
|
||||
// hipRuntimeGetVersion[('int*', 'runtimeVersion')]
|
||||
#define INIT_hipRuntimeGetVersion_CB_ARGS_DATA(cb_data) { \
|
||||
cb_data.args.hipRuntimeGetVersion.runtimeVersion = (int*)runtimeVersion; \
|
||||
@@ -6421,6 +6457,18 @@ static inline void hipApiArgsInit(hip_api_id_t id, hip_api_data_t* data) {
|
||||
// hipProfilerStop[]
|
||||
case HIP_API_ID_hipProfilerStop:
|
||||
break;
|
||||
// hipRegisterActivityCallback[('unsigned int', 'id'), ('void*', 'fun'), ('void*', 'arg')]
|
||||
case HIP_API_ID_hipRegisterActivityCallback:
|
||||
break;
|
||||
// hipRegisterApiCallback[('unsigned int', 'id'), ('void*', 'fun'), ('void*', 'arg')]
|
||||
case HIP_API_ID_hipRegisterApiCallback:
|
||||
break;
|
||||
// hipRemoveActivityCallback[('unsigned int', 'id')]
|
||||
case HIP_API_ID_hipRemoveActivityCallback:
|
||||
break;
|
||||
// hipRemoveApiCallback[('unsigned int', 'id')]
|
||||
case HIP_API_ID_hipRemoveApiCallback:
|
||||
break;
|
||||
// hipRuntimeGetVersion[('int*', 'runtimeVersion')]
|
||||
case HIP_API_ID_hipRuntimeGetVersion:
|
||||
if (data->args.hipRuntimeGetVersion.runtimeVersion) data->args.hipRuntimeGetVersion.runtimeVersion__val = *(data->args.hipRuntimeGetVersion.runtimeVersion);
|
||||
@@ -8971,6 +9019,30 @@ static inline const char* hipApiString(hip_api_id_t id, const hip_api_data_t* da
|
||||
oss << "hipProfilerStop(";
|
||||
oss << ")";
|
||||
break;
|
||||
case HIP_API_ID_hipRegisterActivityCallback:
|
||||
oss << "hipRegisterActivityCallback(";
|
||||
oss << "id=" << data->args.hipRegisterActivityCallback.id;
|
||||
oss << ", fun=" << data->args.hipRegisterActivityCallback.fun;
|
||||
oss << ", arg=" << data->args.hipRegisterActivityCallback.arg;
|
||||
oss << ")";
|
||||
break;
|
||||
case HIP_API_ID_hipRegisterApiCallback:
|
||||
oss << "hipRegisterApiCallback(";
|
||||
oss << "id=" << data->args.hipRegisterApiCallback.id;
|
||||
oss << ", fun=" << data->args.hipRegisterApiCallback.fun;
|
||||
oss << ", arg=" << data->args.hipRegisterApiCallback.arg;
|
||||
oss << ")";
|
||||
break;
|
||||
case HIP_API_ID_hipRemoveActivityCallback:
|
||||
oss << "hipRemoveActivityCallback(";
|
||||
oss << "id=" << data->args.hipRemoveActivityCallback.id;
|
||||
oss << ")";
|
||||
break;
|
||||
case HIP_API_ID_hipRemoveApiCallback:
|
||||
oss << "hipRemoveApiCallback(";
|
||||
oss << "id=" << data->args.hipRemoveApiCallback.id;
|
||||
oss << ")";
|
||||
break;
|
||||
case HIP_API_ID_hipRuntimeGetVersion:
|
||||
oss << "hipRuntimeGetVersion(";
|
||||
if (data->args.hipRuntimeGetVersion.runtimeVersion == NULL) oss << "runtimeVersion=NULL";
|
||||
|
||||
Référencer dans un nouveau ticket
Bloquer un utilisateur